@@ -81,7 +81,7 @@ class ActiveMethod(Method, ABC):
     def get_point(self):
         pass
 
-    def run(self, guard_value: int = 1_000_000):
+    def run(self, guard_value: int = 10_000):
         """ Run optimization. """
         self.recorder.record(self.recorder.RUNNING)
         self.run_steps(guard_value)
@@ -154,3 +154,10 @@ class ActiveMethod(Method, ABC):
             stopping_results.append(criteria.evaluate(self))
 
         return any(stopping_results)
+
+    def _get_steps(self) -> int:
+        from flex_optimization.stop_criteria import StopFunctionEvaluation
+        for stop in self.stop_criterion:
+            if isinstance(stop, StopFunctionEvaluation):
+                return stop.num_eval
+        return 1_000_000
