@@ -1,9 +1,15 @@
 
-from flex_optimization.problem_statement import StopCriteria, Method
-from flex_optimization.method_logger import logger
+from flex_optimization.core.method import Method
+from flex_optimization.core.stop_criteria import StopCriteria
 
 
 class StopFunctionEvaluation(StopCriteria):
+    """
+    Stop Criteria: Function Evaluation
+
+    Stop the algorithm after 'num_eval' function evaluations.
+
+    """
     def __init__(self, num_eval: int = 10):
         self.num_eval = num_eval
         self.current_eval = 0
@@ -12,8 +18,7 @@ class StopFunctionEvaluation(StopCriteria):
         return f"{type(self).__name__} | num_eval: {self.current_eval}"
 
     def evaluate(self, method: Method, *args, **kwargs) -> bool:
-        self.current_eval = method.data.shape[0]
+        self.current_eval = len(method.recorder.data)
         if self.current_eval >= self.num_eval:
             return False
-        logger.debug(f"{type(self).__name__}| current eval: {self.current_eval}/{self.num_eval}")
         return True
